# Security Policy

If we verify a reported security vulnerability, our policy is:

- We will patch the current release branch, as well as the immediate prior minor release branch.

- After patching the release branches, we will immediately issue new security fix releases for each patched release branch.

## Reporting a Security Issue

To report any security issues, please [raise an issue](https://github.com/datakind/Data-Observation-Toolkit/issues/new/choose) and select **Security issue*
